
//This var holds the elementId of the currently playing video. It's used to verify events arriving. We'll only listen to
//video events from the activeVideo. Anything that arrives that isn't this, gets ignored.
var activeVideo = null;

function getVideoPath(idx) {
	var vTag = document.createElement("video");						//dummy video just for feature testing
	var extensions = videos[idx] && videos[idx].extensions || [];	//return the extensions array for this video, or an empty array

	//Loop through the video extensions we have. They'll already be in preferred order
	for(var i=0;i<extensions.length;i++) {
		if(vTag.canPlayType("video/" + extensions[i]) != "") {
			return videos[idx].file_path.replace(".jpg","."+extensions[i]);	//return the path with .jpg replaced with the video extension
		}
	}
	//if we got this far, then have no playable videos for this user so return empty string (which the caller should be checking for)
	return "";
}

function stopVideos() {
	activeVideo = null;

	// stop all the videos
	for(var i = 0; i < videos.length; i++){
		try {
			//pause the video
			var v = document.getElementById("video"+i);
			v && v.pause && v.pause();

			if(mdRewindVideoOnClose && v)	//if the custom var mdRewindVideoOnClose indicates we should rewind
				v.currentTime = 0;			//then set the current video time to zero (so that replays always start from the beginning)

			//hide the panel this video is on
			var vpan = document.getElementById("videoPanel"+i);
			vpan.style.display = "none";
		}
		catch(e) {}
	}

	//hide the video container all the video panels live on
	setContainerVisibility("videoContainer","none");

	//now the video container has been hidden, bring back the image gallery by setting it's style.display property to "block"
	setContainerVisibility("imageGallery","block");
}

function setContainerVisibility(containerId, displaySetting) {	//set the selected container visible or invisible
	var ig = document.getElementById(containerId);
	if(ig)ig.style.display = displaySetting;
	return !!ig;										//return whether setting succeeded, so compound statements can keep going left to right
}

function loadVideo(idx, _imgSlotDiv_applyBackground) {
	var pw = imageGalleryConfig.width, ph = imageGalleryConfig.height - videos[idx].closeButtonClickAllowance;	//videopanel width/height

	//see if the video already exists
	var videoId = "video" + idx;
	var video = document.getElementById(videoId);
	if(video)return;
	
	_imgSlotDiv_applyBackground.style.background = 'url("images/sfondo_video.jpg")';

	//get the video panel and make sure it's height allows the "x" to be clickable
	var vidpan = document.getElementById("videoPanel"+idx);
	vidpan.style.width = pw + "px";
	vidpan.style.height = ph + "px";
	vidpan.style.top = (imageGalleryConfig.height - ph) + "px";

	//get the closebutton div (clb) and the img (clbi)
	var clb = document.getElementById("closeButton");
	var clbi = document.getElementById("closeButtonImg");

	//set the left position of the img to the width of the gallery minus the width of the image (position it top-right corner)
	clb.style.left = (imageGalleryConfig.width - clbi.width)+"px";

	var path = getVideoPath(idx);
	if(path === "")
		return;		//can't play video without a path to a playable video

	// create video if it doesn't yet exist
	video = document.createElement("video");
	video.id = videoId;
	video.src = path;
	video.style.marginTop = posterVideoMarginTop;
	var vw = videos[idx].width, vh = videos[idx].height;	//video height/width default from the videos array

	switch(mdImageScale) {	//0 = do nothing (use what's defined in the videos array), 1 = scale, 2 = stretch to fill panel size
		case 1: 	//scale the values so the video is shown at it's maximum size without getting cropped or changing aspect ratio
			var scaled = scale(pw, ph, vw, vh);
			vw = scaled.width;
			vh = scaled.height;
			break;
		case 2:
			vw = pw;	//video width/height = panel width/height stretched with possible ugly aspect ratio
			vh = ph;
			break;
		case 0:			//do nothing, which means use what's in the videos[idx].width/height defaults
		default:
			break;
	}
	video.width = vw;
	video.height = vh;
	video.style.position = "relative";
	var vsb = mdIncludeBorder ? 1 : 0;
	var vsl = vw < pw ? ((pw - vw) / 2) : 0;
	var vst = vh < ph ? ((ph - vh) / 2) : 0;
	video.style.left = (vsb+vsl)+"px";
	video.style.top = (vsb+vst)+"px";
	video.controls = "controls";

	vidpan.appendChild(video);

	//enable video for EB tracking
	window["EBVideo" + idx] = new EBG.VideoModule(video);
}

function playVideo(idx,_event) {
	stopVideos();										//ensure no other videos are playing/visible
	myStopPropagation(_event);
	
	//get the closebutton div (clb)
	var clb = document.getElementById("closeButton");
	clb.style.display = "block";	//it defaults to none in the css, we don't set it visible until now

	activeVideo = "video" + idx;

	var vid = document.getElementById(activeVideo);
	if(vid) {
		setContainerVisibility("imageGallery","none");
		setContainerVisibility("videoContainer","block");
		var vidpan = document.getElementById("videoPanel"+idx);
		vidpan.style.display = "block";

		if(clientDetector.ios && clientDetector.ua.match(/\sos\s5_/i) != null){
			setTimeout(function(){vid.play()},50);
		}
		else {
			vid.play();
		}
	}
}

function setCustomVar(customVarName, defaultValue, parseNum) {	//create global var with name = str, taking value from adConfig if it's there, else use default
	//if(EB._adConfig != null){
	if(EB != null){
	//var value = EB._adConfig.hasOwnProperty(customVarName) ? EB._adConfig[customVarName] : defaultValue;
	var value = defaultValue;
	if (value === "true") value = true;
	if (value === "false") value = false;
	if (value === "undefined") value = undefined;
	if (arguments.length == 3 && parseNum && typeof value === "string") value = parseFloat(value);
	window[customVarName] = value;
	}
}

function setMyCustomVariables(){
	try{if(EB._adConfig.customJSVars.autoSlideTimer != null){autoSlideTimer = EB._adConfig.customJSVars.autoSlideTimer}}catch(e){};
}

function myStopPropagation(e){

	if (!e)
	  e = window.event;

	//IE9 & Other Browsers
	if (e.stopPropagation) {
	  e.stopPropagation();
	}
	//IE8 and Lower
	else {
	  e.cancelBubble = true;
	}
}

function scale(containerWidth, containerHeight, imgWidth, imgHeight) {
	var ratio = Math.min(containerWidth / imgWidth, containerHeight / imgHeight);
	return { width: imgWidth*ratio, height: imgHeight*ratio };
}

function slideAvantiAutomaticamente(){
	myImageGallery._stepToStop(-1);
}

function setMyAutoSlideInterval(){
	try{
		window.clearInterval(autoSlideInterval);
	}catch(e){}
	autoSlideInterval = window.setInterval(slideAvantiAutomaticamente, autoSlideTimer);
}

function stopMyAutoSlideInterval(){
	try{
		window.clearInterval(autoSlideInterval);
	}catch(e){}
}

function showFingerAnimation(_img, _first){
	if(showHandAnimation){
		_first = typeof _first !== 'undefined' ? _first : false; 
		var finger = document.getElementById("Finger"+_img);
		//var _delay = ((autoSlideTimer - 800 ) / 1000) + (3*(_img-1));
		var _delay = (autoSlideTimer - 1700 ) / 1000;
		
		if(_first)
		_delay += .6; 
		
		TweenMax.to(finger,.5,{alpha:1, ease: Power0.easeNone, delay:_delay});
		TweenMax.to(finger,1,{marginLeft:-80, ease: Power4.easeInOut, delay:_delay, onComplete:function(){
			TweenMax.set(finger,{alpha:0, marginLeft:0});
		}});
	}
}




